#!/bin/bash
#
# Recipe-specific step for task Configure: task.configure.openssl-native_3.0.5-r0 (configure.sh)
#
# This script was imported from Yocto but may have been modified locally
#

if [ -r "$PLATFORM_LOC/scripts/utils.sh" ]; then
	source "$PLATFORM_LOC/scripts/utils.sh"
else
	source "$script_lib_dir/utils.sh"
fi

function local_do_configure() {
	# When we upgrade glibc but not uninative we see obtuse failures in openssl. Make
	# the issue really cle$[AR] that perl isn't functional due to symbol mismatch issues.
	cat <<- EOF > ${workDir}/perltest
	#!/usr/bin/env perl
	use POSIX;
	EOF
	log_run chmod a+x ${workDir}/perltest
	${workDir}/perltest

	os=linux
	case $os in
	linux-gnueabi |\
	linux-gnuspe |\
	linux-musleabi |\
	linux-muslspe |\
	linux-musl )
		os=linux
		;;
	*)
		;;
	esac
	target="$os-x86_64"
	case $target in
	linux-arc)
		target=linux-latomic
		;;
	linux-arm*)
		target=linux-armv4
		;;
	linux-aarch64*)
		target=linux-aarch64
		;;
	linux-i?86 | linux-viac3)
		target=linux-x86
		;;
	linux-gnux32-x86_64 | linux-muslx32-x86_64 )
		target=linux-x32
		;;
	linux-gnu64-x86_64)
		target=linux-x86_64
		;;
	linux-mips | linux-mipsel)
		# specifying TARGET_CC_ARCH prevents $[recipe_base_name] from (incorrectly) adding target architecture flags
		target="linux-mips32 "
		;;
	linux-gnun32-mips*)
		target=linux-mips64
		;;
	linux-*-mips64 | linux-mips64 | linux-*-mips64el | linux-mips64el)
		target=linux64-mips64
		;;
	linux-microblaze* | linux-nios2* | linux-sh3 | linux-sh4 | linux-arc*)
		target=linux-generic32
		;;
	linux-powerpc)
		target=linux-ppc
		;;
	linux-powerpc64)
		target=linux-ppc64
		;;
	linux-powerpc64le)
		target=linux-ppc64le
		;;
	linux-riscv32)
		target=linux-generic32
		;;
	linux-riscv64)
		target=linux-generic64
		;;
	linux-sparc | linux-supersparc)
		target=linux-sparcv9
		;;
	mingw32-x86_64)
		target=mingw64
		;;
	esac

	useprefix=${prefix}
	if [ "x$useprefix" = "x" ]; then
		useprefix=
	fi
	# WARNING: do not set compiler/linker flags (-I/-D etc.) in EXTRA_OECONF, as they will fully replace the
	# environment variables set by bitbake. Adjust the environment variables instead.
	HASHBANGPERL="/usr/bin/env perl" PERL=perl PERL5LIB="${srcDir}/external/perl/Text-Template-1.46/lib" \
	log_run perl ${srcDir}/Configure --with-rand-seed=os,devrandom  disable-devcryptoeng  --prefix=$useprefix --openssldir=${libdir}/ssl-3 --libdir=${libdir} $target
	log_run perl ${buildDir}/configdata.pm --dump
}

do_buildstep_prepend

local_do_configure

do_buildstep_append

