#!/bin/bash
# Script to run package configure

if [ -r "$PLATFORM_LOC/scripts/utils.sh" ]; then
	source "$PLATFORM_LOC/scripts/utils.sh"
else
	source "$script_lib_dir/utils.sh"
fi

do_prepare_config () {
	export KCONFIG_NOTIMESTAMP=1

	sed -e '/CONFIG_STATIC/d' \
		< ${WORKDIR}/defconfig > ${S}/.config
	echo "# CONFIG_STATIC is not set" >> .config
	for i in 'CROSS' 'DISTRO FEATURES'; do echo "### $i"; done >> \
		${S}/.config
	sed -i -e '${configmangle}' ${S}/.config
	if test ${DO_IPv4} -eq 0 && test ${DO_IPv6} -eq 0; then
		# disable networking applets
		mv ${S}/.config ${S}/.config.sw-tmp
		awk 'BEGIN{net=0}
		/^# Networking Utilities/{net=1}
		/^#$/{if(net){net=net+1}}
		{if(net==2&&$0 !~ /^#/&&$1){print("# "$1" is not set")}else{print}}' \
		${S}/.config.sw-tmp > ${S}/.config
	fi
	sed -i 's/CONFIG_IFUPDOWN_UDHCPC_CMD_OPTIONS="-R -n"/CONFIG_IFUPDOWN_UDHCPC_CMD_OPTIONS="-R -b"/' ${S}/.config
}

do_buildstep_prepend

do_prepare_config

sed -i -e '/^[# ]*CONFIG_RFKILL[ =].*$/c\CONFIG_RFKILL=y' .config

for conf in $BUSYBOX_CONFIG; do
	case $conf in
		getopts)
			log_exec ${B}/merge_config.sh -m .config getopts.cfg
			;;
		init)
			log_exec ${B}/merge_config.sh -m .config init.cfg
			;;
		login-utilities)
			log_exec ${B}/merge_config.sh -m .config login-utilities.cfg
			;;
		mdev)
			log_exec ${B}/merge_config.sh -m .config mdev.cfg
			;;
		mount-via-label)
			log_exec ${B}/merge_config.sh -m .config mount-via-label.cfg
			;;
		gprep)
			log_exec ${B}/merge_config.sh -m .config gprep.cfg
			;;
		sha1sum)
			log_exec ${B}/merge_config.sh -m .config sha1sum.cfg
			;;
		sha256sum)
			log_exec ${B}/merge_config.sh -m .config sha256sum.cfg
			;;
		syslog)
			log_exec ${B}/merge_config.sh -m .config syslog.cfg
			;;
		unicode)
			log_exec merge_config.sh -m .config unicode.cfg
			;;			
		*)
			warning 1 "BUSYBOX_CONFIG \"$conf\" is not supported"
			;;
	esac
done

unset CFLAGS CPPFLAGS CXXFLAGS LDFLAGS
yes '' | do_make oldconfig

do_buildstep_append


