# Append script for task Install: task.install.systemd_250.5-r0 (meson-install-append.sh)
# This script was imported from Yocto but may have been modified locally

: ${HAS_SYSVINIT:="false"}
: ${HAS_UTMP:="false"}
: ${HAS_NETWORKD:="false"}
: ${HAS_RESOLVED:="false"}
: ${HAS_POLKIT:="false"}

	log_run install -d ${installDir}/${base_sbindir}
	if true; then
		# Provided by a separate recipe
		rm ${installDir}${base_libdir}/${recipe_name}/system/serial-getty* -f
	fi

	# Provide support for initramfs
	[ ! -e ${installDir}/init ] && ln -s ${base_libdir}/${recipe_name}/${recipe_base_name} ${installDir}/init
	[ ! -e ${installDir}/${base_sbindir}/udevd ] && ln -s ${base_libdir}/${recipe_name}/systemd-udevd ${installDir}/${base_sbindir}/udevd

	log_run install -d ${installDir}${sysconfdir}/udev/rules.d
	log_run install -d ${installDir}${sysconfdir}/tmpfiles.d
	for rule in $(find ${workDir} -maxdepth 1 -type f -name "*.rules"); do
		log_run install -m 0644 $rule ${installDir}${sysconfdir}/udev/rules.d
	done

	log_run install -m 0644 ${workDir}/00-create-volatile.conf ${installDir}${sysconfdir}/tmpfiles.d

	if ${HAS_SYSVINIT}; then
		log_run install -d ${installDir}${sysconfdir}/init.d
		log_run install -m 0755 ${workDir}/init ${installDir}${sysconfdir}/init.d/systemd-udevd
		sed -i s%@UDEVD@%${base_libdir}/${recipe_name}/systemd-udevd% ${installDir}${sysconfdir}/init.d/systemd-udevd
		log_run install -Dm 0755 ${srcDir}/src/systemctl/systemd-sysv-install.SKELETON ${installDir}${base_libdir}/${recipe_name}/systemd-sysv-install
	fi

	if "true"; then
		# $[localstatedir]/log is typically a symbolic link to inside $[localstatedir]/volatile,
		# which is expected to be empty.
		rm -rf ${installDir}${localstatedir}/log
	else
		log_run chown root:systemd-journal ${installDir}${localstatedir}/log/journal

		# journal-remote creates this at start
		rm -rf ${installDir}${localstatedir}/log/journal/remote
	fi

	log_run install -d ${installDir}${base_libdir}/${recipe_name}/system/graphical.target.wants
	log_run install -d ${installDir}${base_libdir}/${recipe_name}/system/multi-user.target.wants
	log_run install -d ${installDir}${base_libdir}/${recipe_name}/system/poweroff.target.wants
	log_run install -d ${installDir}${base_libdir}/${recipe_name}/system/reboot.target.wants
	log_run install -d ${installDir}${base_libdir}/${recipe_name}/system/rescue.target.wants

	# Create symlinks for systemd-update-utmp-runlevel.service
	if [ "${HAS_UTMP}" = "true" ]; then
		log_run ln -sf ../systemd-update-utmp-runlevel.service ${installDir}${base_libdir}/${recipe_name}/system/graphical.target.wants/systemd-update-utmp-runlevel.service
		log_run ln -sf ../systemd-update-utmp-runlevel.service ${installDir}${base_libdir}/${recipe_name}/system/multi-user.target.wants/systemd-update-utmp-runlevel.service
		log_run ln -sf ../systemd-update-utmp-runlevel.service ${installDir}${base_libdir}/${recipe_name}/system/poweroff.target.wants/systemd-update-utmp-runlevel.service
		log_run ln -sf ../systemd-update-utmp-runlevel.service ${installDir}${base_libdir}/${recipe_name}/system/reboot.target.wants/systemd-update-utmp-runlevel.service
		log_run ln -sf ../systemd-update-utmp-runlevel.service ${installDir}${base_libdir}/${recipe_name}/system/rescue.target.wants/systemd-update-utmp-runlevel.service
	fi

	# this file is needed to exist if networkd is disabled but timesyncd is still in use since timesyncd checks it
	# for existence else it fails
	if [ -s ${installDir}${libdir}/tmpfiles.d/systemd.conf ] &&
	   ! ${HAS_NETWORKD}; then
		echo 'd /run/'"${recipe_name}"'/netif/links 0755 root root -' >>${installDir}${libdir}/tmpfiles.d/systemd.conf
	fi
	if ! ${HAS_RESOLVED}; then
		echo 'L! '"${sysconfdir}"'/resolv.conf - - - - ../run/'"${recipe_name}"'/resolve/resolv.conf' >>${installDir}${libdir}/tmpfiles.d/etc.conf
		echo 'd /run/'"${recipe_name}"'/resolve 0755 root root -' >>${installDir}${libdir}/tmpfiles.d/systemd.conf
		echo 'f /run/'"${recipe_name}"'/resolve/resolv.conf 0644 root root' >>${installDir}${libdir}/tmpfiles.d/systemd.conf
		log_run ln -s ../run/${recipe_name}/resolve/resolv.conf ${installDir}${sysconfdir}/resolv-conf.systemd
	else
		sed -i -e "s%^L! ${sysconfdir}/resolv.conf.*\$%L! ${sysconfdir}/resolv.conf - - - - ../run/${recipe_name}/resolve/resolv.conf%g" ${installDir}${libdir}/tmpfiles.d/etc.conf
		log_run ln -s ../run/${recipe_name}/resolve/resolv.conf ${installDir}${sysconfdir}/resolv-conf.systemd
	fi
	if true; then
		rm ${installDir}${libdir}/tmpfiles.d/x11.conf
		rm -r ${installDir}${sysconfdir}/X11
	fi

	# If polkit is setup fixup permissions and ownership
	if ${HAS_POLKIT}; then
		if [ -d ${installDir}${datadir}/polkit-1/rules.d ]; then
			log_run chmod 700 ${installDir}${datadir}/polkit-1/rules.d
			log_run chown polkitd:root ${installDir}${datadir}/polkit-1/rules.d
		fi
	fi

	# If polkit is not available and a fallback was requested, install a drop-in that allows networkd to
	# request hostname changes via DBUS without elevating its privileges
	if false; then
		log_run install -d ${installDir}${base_libdir}/${recipe_name}/system/systemd-hostnamed.service.d
		log_run install -m 0644 ${workDir}/00-hostnamed-network-user.conf ${installDir}${base_libdir}/${recipe_name}/system/systemd-hostnamed.service.d
		log_run install -d ${installDir}${datadir}/dbus-1/system.d
		log_run install -m 0644 ${workDir}/org.freedesktop.hostname1_no_polkit.conf ${installDir}${datadir}/dbus-1/system.d
	fi

	# create link for existing udev rules
	log_run ln -s ${base_bindir}/udevadm ${installDir}${base_sbindir}/udevadm

	# install default policy for presets
	# https://www.freedesktop.org/wiki/Software/$[recipe_name]/Preset#howto
	log_run install -Dm 0644 ${workDir}/99-default.preset ${installDir}${base_libdir}/${recipe_name}/system-preset/99-default.preset

	# add a profile fragment to disable $[recipe_name] pager with busybox less
	log_run install -Dm 0644 ${workDir}/systemd-pager.sh ${installDir}${sysconfdir}/profile.d/systemd-pager.sh
    #Remove this service useless for our needs
    rm -f ${installDir}/${base_libdir}/${recipe_name}/system-generators/systemd-gpt-auto-generator
