#!/bin/bash
#
# Recipe-specific step for task Install: task.install.util-linux_2.37.4-r0 (make_install.sh)
#
# This script was imported from Yocto but may have been modified locally
#

if [ -r "$PLATFORM_LOC/scripts/utils.sh" ]; then
	source "$PLATFORM_LOC/scripts/utils.sh"
else
	source "$script_lib_dir/utils.sh"
fi

function local_do_make_install() {
	# with ccache the timestamps on compiled files may
	# end up earlier than on their inputs, this allows
	# for the resultant compilation in the install step.
	do_make 'CC='"${CC}" 'LD='"${LD}" \
		'LDFLAGS=-Wl,-O1 -Wl,--hash-style=gnu -Wl,--as-needed -fmacro-prefix-map='"${workDir}"'='"${prefix}"'/src/debug/'"${recipe_name}"'/2.37.4-r0                      -fdebug-prefix-map='"${workDir}"'='"${prefix}"'/src/debug/'"${recipe_name}"'/2.37.4-r0                      -fdebug-prefix-map='"${TARGET_SYSROOT_LOC}"'=                      -fdebug-prefix-map='"${NATIVE_SYSROOT_LOC}"'= ' 'DESTDIR='"${installDir}" install

	log_run mkdir -p ${installDir}${base_bindir}

	sbinprogs="agetty ctrlaltdel cfdisk vipw vigr"
	sbinprogs_a="pivot_root hwclock mkswap losetup swapon swapoff fdisk fsck blkid blockdev fstrim sulogin switch_root nologin"
	binprogs_a="dmesg getopt kill more umount mount login su mountpoint"

	if [ "${base_sbindir}" != "${sbindir}" ]; then
		log_run mkdir -p ${installDir}${base_sbindir}
		for p in $sbinprogs $sbinprogs_a; do
			if [ -f "${installDir}${sbindir}/$p" ]; then
				log_run mv "${installDir}${sbindir}/$p" "${installDir}${base_sbindir}/$p"
			fi
		done
	fi

	if [ "${base_bindir}" != "${bindir}" ]; then
		log_run mkdir -p ${installDir}${base_bindir}
		for p in $binprogs_a; do
			if [ -f "${installDir}${bindir}/$p" ]; then
				log_run mv "${installDir}${bindir}/$p" "${installDir}${base_bindir}/$p"
			fi
		done
	fi

	log_run install -d ${installDir}${sysconfdir}/default
	echo 'MOUNTALL="-t nonfs,nosmbfs,noncpfs"' > ${installDir}${sysconfdir}/default/mountall

	rm -f ${installDir}${bindir}/chkdupexe
	if [ "pam" ]; then
		log_run install -d ${installDir}${sysconfdir}/pam.d
		log_run install -m 0644 ${workDir}/runuser.pamd ${installDir}${sysconfdir}/pam.d/runuser
		log_run install -m 0644 ${workDir}/runuser-l.pamd ${installDir}${sysconfdir}/pam.d/runuser-l
		# Required for "su -" aka "su --login" because
		# otherwise it uses "other", which has "auth pam_deny.so"
		# and thus prevents the operation.
		log_run ln -s su ${installDir}${sysconfdir}/pam.d/su-l
	fi
	rm -rf ${installDir}${includedir}/uuid ${installDir}${prefix}${libdir}/pkgconfig/uuid.pc ${installDir}${prefix}${libdir}/libuuid* ${installDir}${libdir}/libuuid*
}

do_buildstep_prepend

local_do_make_install

do_buildstep_append

