#!/bin/bash
#
# Recipe-specific step for task Configure: task.configure.qemu-native_6.2.0-r0 (configure.sh)
#
# This script was imported from Yocto but may have been modified locally
#

if [ -r "$PLATFORM_LOC/scripts/utils.sh" ]; then
	source "$PLATFORM_LOC/scripts/utils.sh"
else
	source "$script_lib_dir/utils.sh"
fi

function local_do_configure() {
	# Append build host pkg-config paths for native target since the host may provide sdl
	BHOST_PKGCONFIG_PATH=$(PATH=/usr/bin:/bin pkg-config --variable pc_path pkg-config || echo "")
	if [ ! -z "$BHOST_PKGCONFIG_PATH" ]; then
		export PKG_CONFIG_PATH=$PKG_CONFIG_PATH:$BHOST_PKGCONFIG_PATH
	fi
	# This is taken from meson.bbclass to avoid errors when updating to a
	# new version of meson.
	rmdir ${libdir}/python3.10/site-packages/*.egg-info 2>/dev/null || :

	${srcDir}/configure --prefix=${prefix} --bindir=${bindir} --includedir=${includedir} --libdir=${libdir} --mandir=${mandir} --datadir=${datadir} --docdir=${datadir}/doc/${recipe_base_name} --sysconfdir=${sysconfdir} --libexecdir=${libexecdir} --localstatedir=${NATIVE_SYSROOT_LOC}/v${AR} \
		--with-suffix=${recipe_base_name} --disable-strip --disable-werror --extra-cflags='-isystem'"${includedir}"' -O2 -pipe' --extra-ldflags='-L'"${libdir}"' -L'"${base_libdir}"' -Wl,--enable-new-dtags -Wl,-rpath-link,'"${libdir}"' -Wl,-rpath-link,'"${base_libdir}"' -Wl,-rpath,'"${libdir}"' -Wl,-rpath,'"${base_libdir}"' -Wl,-O1 -Wl,--allow-shlib-undefined -fuse-ld=bfd' \
		 --with-git=/bin/false --with-git-submodules=ignore --meson=meson \
		--disable-linux-aio --disable-attr --disable-bpf --disable-brlapi --disable-bzip2 --disable-capstone --disable-curses --disable-opengl --disable-fdt --disable-gcrypt --disable-glusterfs --disable-gnutls --disable-gtk --disable-kvm --disable-cap-ng --disable-curl --disable-libiscsi --disable-libnfs --disable-libudev --disable-libusb --disable-libxml2 --disable-lzo --disable-nettle --disable-smartcard --disable-numa --enable-pie --disable-libpmem --disable-pa --disable-rbd --disable-rdma --disable-sdl --disable-seccomp --disable-selinux --disable-slirp --disable-snappy --disable-spice --disable-libssh --disable-usb-redir --enable-trace-backend=nop --disable-vde --disable-vhost-net --disable-virglrenderer --disable-virtfs --disable-vnc-jpeg --disable-vnc-png --disable-vnc-sasl --disable-vte --disable-xen --disable-xfsctl --disable-xkbcommon \
		--target-list=arm-linux-user,aarch64-linux-user,riscv32-linux-user,riscv64-linux-user,x86_64-linux-user --disable-tools --disable-blobs --disable-guest-agent
}

do_buildstep_prepend

local_do_configure

do_buildstep_append

