#!/bin/bash
#
# Recipe-specific step for task Install: task.install.shadow-native_4.11.1-r0 (make_install.sh)
#
# This script was imported from Yocto but may have been modified locally
#

if [ -r "$PLATFORM_LOC/scripts/utils.sh" ]; then
	source "$PLATFORM_LOC/scripts/utils.sh"
else
	source "$script_lib_dir/utils.sh"
fi

function local_do_make_install() {
	do_make DESTDIR="${installDir}" sbindir="${base_sbindir}" usbindir="${sbindir}" install

	# Info dir listing isn't interesting at this point so remove it if it exists.
	if [ -e "${installDir}${infodir}/dir" ]; then
		rm -f ${installDir}${infodir}/dir
	fi

	# Enable CREATE_HOME by default.
	sed -i 's#CREATE_HOME/CREATE_HOME/g' ${installDir}${sysconfdir}/login.defs

	# As we are on an embedded system, ensure the users mailbox is in
	# ~ not /v$[AR]/spool/mail by default, as who knows where or how big
	# /v$[AR] is. The system MDA will set this later anyway.
	sed -i 's/MAIL_DIR#MAIL_DIR/g' ${installDir}${sysconfdir}/login.defs
	sed -i 's#MAIL_FILE/MAIL_FILE/g' ${installDir}${sysconfdir}/login.defs

	# Disable checking emails.
	sed -i 's/MAIL_CHECK_ENAB#MAIL_CHECK_ENAB/g' ${installDir}${sysconfdir}/login.defs

	# Comment out SU_NAME to work correctly with busybox
	# See Bug#5359 and Bug#7173
	sed -i 's:^SU_NAME:#SU_NAME:g' ${installDir}${sysconfdir}/login.defs

	# Use proper encryption for passwords
	sed -i 's/^#ENCRYPT_METHOD.*$/ENCRYPT_METHOD SHA512' ${installDir}${sysconfdir}/login.defs

	log_run install -d ${installDir}${sysconfdir}/default
	log_run install -m 0644 ${workDir}/useradd ${installDir}${sysconfdir}/default
	# Ensure that the image has as a /v$[AR]/spool/mail dir so $[recipe_base_name] can
	# put mailboxes there if the user reconfigures $[recipe_base_name] to its
	# defaults (see sed below).
	log_run install -m 0775 -d ${installDir}${NATIVE_SYSROOT_LOC}/v${AR}/spool/mail
	log_run chown root:mail ${installDir}${NATIVE_SYSROOT_LOC}/v${AR}/spool/mail

	if [ -e ${workDir}/pam.d ]; then
		log_run install -d ${installDir}${sysconfdir}/pam.d
		log_run install -m 0644 ${workDir}/pam.d/* ${installDir}${sysconfdir}/pam.d
		# Remove defaults that are not used when supporting PAM.
		sed -i -f ${workDir}/login_defs_pam.sed ${installDir}${sysconfdir}/login.defs
	fi

	log_run install -d ${installDir}${sbindir} ${installDir}${base_sbindir} ${installDir}${base_bindir}

	# Move binaries to the locations we want
	rm ${installDir}${sbindir}/vigr
	log_run ln -sf vipw.shadow ${installDir}${base_sbindir}/vigr
	if [ "${sbindir}" != "${base_sbindir}" ]; then
		log_run mv ${installDir}${sbindir}/vipw ${installDir}${base_sbindir}/vipw
	fi
	if [ "${bindir}" != "${base_bindir}" ]; then
		log_run mv ${installDir}${bindir}/login ${installDir}${base_bindir}/login
		log_run mv ${installDir}${bindir}/su ${installDir}${base_bindir}/su
	fi

	# Handle link properly after rename, otherwise missing files would
	# lead rpm failed dependencies.
	log_run ln -sf newgrp.shadow ${installDir}${bindir}/sg

	# usermod requires the subuid/subgid files to be in place before being
	# able to use the -v/-V flags otherwise it fails:
	# usermod: /etc/subuid does not exist, you cannot use the flags -v or -V
	log_run install -d ${installDir}${sysconfdir}
	touch ${installDir}${sysconfdir}/subuid
	touch ${installDir}${sysconfdir}/subgid
}

do_buildstep_prepend

local_do_make_install

do_buildstep_append

