#!/bin/bash
#
# Recipe-specific step for task Compile: task.compile.u-boot-tools-native_2022.01-r0 (make_all.sh)
#
# This script was imported from Yocto but may have been modified locally
#

if [ -r "$PLATFORM_LOC/scripts/utils.sh" ]; then
	source "$PLATFORM_LOC/scripts/utils.sh"
else
	source "$script_lib_dir/utils.sh"
fi

function local_do_make_all() {
	# Yes, this is crazy. If you build on a system with git < 2.14 from scratch, the tree will
	# be marked $[AS]"dirty" and the version will include "-dirty", leading to a reproducibility problem.
	# The issue is the inode count for Licnses/README changing due to do_populate_lic hardlinking a
	# copy of the file. We avoid this by ensuring the index is updated with a "git diff" before the
	# u-boot machinery tries to determine the version.
	#
	# build$ ../git/scripts/setlocalversion ../git
	# ""
	# build$ ln ../git
	# build$ ln ../git/README ../foo
	# build$ ../git/scripts/setlocalversion ../git
	# ""-dirty
	# (i.e. creating a hardlink dirties the index)
	cd ${srcDir}; git diff; cd ${buildDir}

	do_make -C ${srcDir} sandbox_defconfig O=${buildDir}

	# Disable CONFIG_CMD_LICENSE, license.h is not used by tools and
	# generating it requires bin2header tool, which for target build
	# is built with target tools and thus cannot be executed on host.
	sed -i -e "s/CONFIG_CMD_LICENSE=.*# CONFIG_CMD_LICENSE is not set"  ${buildDir}/.config

	do_make -C ${srcDir} cross_tools NO_SDL=1 O=${buildDir}
}

do_buildstep_prepend

local_do_make_all

do_buildstep_append

