# Prepend script for task Configure: task.configure.gobject-introspection_1.72.0-r0 (meson-configure-prepend.sh)
# This script was imported from Yocto but may have been modified locally

	# Write out a qemu wrapper that will be given to gi-scanner so that it
	# can run target helper binaries through that.
	qemu_binary="PSEUDO_UNLOAD=1 qemu-${arch_name} -r 3.2.0  -L \${TARGET_SYSROOT_LOC} -E LD_LIBRARY_PATH=\$GIR_EXTRA_LIBS_PATH:.libs:$STAGING_DIR_HOST/${libdir}:$STAGING_DIR_HOST/${base_libdir} "
	cat > ${buildDir}/g-ir-scanner-qemuwrapper << EOF
#!/bin/sh
# Use a modules directory which doesn't exist so we don't load random things
# which may then get deleted (or their dependencies) and potentially segfault
export GIO_MODULE_DIR=${TARGET_SYSROOT_LOC}${libdir}/gio/modules-dummy

$qemu_binary "\$@"
if [ \$? -ne 0 ]; then
    echo "If the above error message is about missing .so libraries, then setting up GIR_EXTRA_LIBS_PATH in the recipe should help."
    echo "(typically like this: GIR_EXTRA_LIBS_PATH=\"\$""{B}/something/.libs\" )"
    exit 1
fi
EOF
	log_run chmod +x ${buildDir}/g-ir-scanner-qemuwrapper

	# Write out a wrapper for g-ir-scanner itself, which will be used when building introspection files
	# for glib-based packages. This wrapper calls the native version of the scanner, and tells it to use
	# a qemu wrapper for running transient target binaries produced by the scanner, and an include directory
	# from the target sysroot.
	cat > ${buildDir}/g-ir-scanner-wrapper << EOF
#!/bin/sh
# This prevents g-ir-scanner from writing cache data to user's HOME dir
export GI_SCANNER_DISABLE_CACHE=1

g-ir-scanner --lib-dirs-envvar=GIR_EXTRA_LIBS_PATH --use-binary-wrapper=${TARGET_SYSROOT_LOC}${bindir}/g-ir-scanner-qemuwrapper --use-ldd-wrapper=${TARGET_SYSROOT_LOC}${bindir}/g-ir-scanner-lddwrapper --add-include-path=${TARGET_SYSROOT_LOC}${datadir}/gir-1.0 --add-include-path=${TARGET_SYSROOT_LOC}${libdir}/gir-1.0 "\$@"
EOF
	log_run chmod +x ${buildDir}/g-ir-scanner-wrapper

	# Write out a wrapper for g-ir-compiler, which runs the target version of it through qemu.
	# g-ir-compiler writes out the raw content of a C struct to disk, and therefore is architecture dependent.
	cat > ${buildDir}/g-ir-compiler-wrapper << EOF
#!/bin/sh	
${TARGET_SYSROOT_LOC}${bindir}/g-ir-scanner-qemuwrapper ${TARGET_SYSROOT_LOC}${bindir}/g-ir-compiler "\$@"
EOF
	log_run chmod +x ${buildDir}/g-ir-compiler-wrapper

	# Write out a wrapper to use instead of ldd, which does not work when a binary is built
	# for a different architecture
	cat > ${buildDir}/g-ir-scanner-lddwrapper << EOF
#!/bin/sh
$OBJDUMP -p "\$@"
EOF
	log_run chmod +x ${buildDir}/g-ir-scanner-lddwrapper

	# Also tweak the target python scripts so that they don't refer to the
	# native version of python binary (the solution is taken from glib-2.0 recipe)
	sed -i -e '1s,#!.*,#!'"${bindir}"'/env python3,' ${srcDir}/tools/g-ir-tool-template.in
	# Need to use ||true as this is only needed if configure.ac both exists
	# and uses GTK_DOC_CHECK.
	gtkdocize --srcdir ${srcDir} --docdir ${srcDir} || true
