#!/bin/bash
# Generic buildstep script
if [ -r "$PLATFORM_LOC/scripts/utils.sh" ]; then
	source "$PLATFORM_LOC/scripts/utils.sh"
else
	source "$script_lib_dir/utils.sh"
fi

# Create custom meson file using gobject wrappers for cross compiling
function local_do_write_config() {
	cat > ${MESON_MACHINE} <<- EOF
		#
		# Automatically generated - Do NOT edit
		#

		[build_machine]
			system = '$bld_config_os'
			cpu_family = '$(meson_normalize_arch $bld_config_arch)'
			cpu = '$recipe_build_arch'
			endian = '$bld_config_endian' 
	EOF
	if $recipe_is_native || $recipe_is_cross; then
	    cat >> ${MESON_MACHINE} <<- EOF
	    
			[binaries]
				c = '${native_build_alias}-gcc'
				cpp = '${native_build_alias}-g++'
				ar = '${native_build_alias}-ar'
				nm = '${native_build_alias}-nm'
				strip = '${native_build_alias}-strip'
				readelf = '${native_build_alias}-readelf'
				pkgconfig = '${native_build_alias}-pkg-config'

			[host_machine]
				system = '$bld_config_os'
				cpu_family = '$(meson_normalize_arch $bld_config_arch)'
				cpu = '$recipe_build_arch'
				endian = '$bld_config_endian' 
		EOF
	else # Normal cross-compiled package
	    cat >> ${MESON_MACHINE} <<- EOF
	    
			[binaries]
				c = '${arch_compiler_prefix}-gcc'
				cpp = '${arch_compiler_prefix}-g++'
				ar = '${arch_compiler_prefix}-ar'
				nm = '${arch_compiler_prefix}-nm'
				strip = '${arch_compiler_prefix}-strip'
				readelf = '${arch_compiler_prefix}-readelf'
				pkgconfig = '${arch_compiler_prefix}-pkg-config'
				g-ir-scanner = '${SYSROOT_LOC}${bindir}/g-ir-scanner-wrapper'
				g-ir-compiler = '${SYSROOT_LOC}${bindir}/g-ir-compiler-wrapper'

			[host_machine]
				system = 'linux-gnueabi'
				cpu_family = '$(meson_normalize_arch ${arch_name})'
				cpu = '${arch_name}'
				endian = '${cpu_config_endian}'
		EOF
	fi
	if $recipe_is_cross; then
	    cat >> ${MESON_MACHINE} <<- EOF
	    
			[target_machine]
				system = 'linux-gnueabi'
				cpu_family = '$(meson_normalize_arch ${arch_name})'
				cpu = '${arch_name}'
				endian = '${cpu_config_endian}'
		EOF
	fi

	cat >> ${MESON_MACHINE} <<- EOF

		[properties]
			c_args = $(meson_array $MESON_C_ARGS)
			c_link_args = $(meson_array $MESON_LINK_ARGS)
			cpp_args = $(meson_array $MESON_CPP_ARGS)
			cpp_link_args = $(meson_array $MESON_LINK_ARGS)
	EOF
	if $recipe_is_native || $recipe_is_cross; then
		cat >> ${MESON_MACHINE} <<- EOF
			needs_exe_wrapper = false
		EOF
	else
		cat >> ${MESON_MACHINE} <<- EOF
			needs_exe_wrapper = true
			gtkdoc_exe_wrapper = '${buildDir}/gtkdoc-qemuwrapper'
			exe_wrapper = 'qemu'
			sys_toot = '$SYSROOT_LOC'
		EOF
	fi
}

function local_do_configure() {
    # Meson requires native toolset to configure, temporary unset the following variables
    # to avoid using cross compiler to build native executable (eg. sanity check tool)
    unset AR LD NM CC CPP CXX READELF STRIP
    
	if $recipe_is_native || $recipe_is_cross; then
		meson_override_native_tools
	else
		export PKG_CONFIG="${configure_build_prefix}pkg-config"
	fi
	local_do_write_config

    # Work around "Meson fails if /tmp is mounted with noexec #2972"
    mkdir -p "${buildDir}/meson-private/tmp"
    export TMPDIR="${buildDir}/meson-private/tmp"
    export STAGING_INCDIR
	export STAGING_LIBDIR
	
    log Executing meson ${meson_extra_flags}...
	log_exec meson setup ${MACHINE_FILE} "${MESONOPTS[@]}" ${meson_extra_flags} "${buildDir}" "${MESON_SOURCEPATH}"
}

do_buildstep_prepend

local_do_configure

do_buildstep_append
