# Append script for task Install: task.install.python3-native_3.10.4-r0 (make_install-append.sh)
# This script was imported from Yocto but may have been modified locally

	# Make sure we use /usr/bin/env python
	for PYTHSCRIPT in `grep -rIl ${bindir}/python ${installDir}${prefix}/bin/python3-native`; do
		sed -i -e '1s|^#!.*|#!/usr/bin/env python3|' $PYTHSCRIPT
	done
	# Add a symlink to the native Python so that scripts can just invoke
	# "nativepython" and get the right one without needing absolute paths
	# (these often end up too long for the #! parser in the kernel as the
	# buffer is 128 bytes long).
	log_run ln -s ${recipe_name}/${recipe_base_name} ${installDir}${prefix}/bin/nativepython3

	# Remove the opt-1.pyc and opt-2.pyc files. There are over 3,000 of them
	# and the overhead in each recipe-sysroot-native isn't worth it, particularly
	# when they're only used for python called with -O or -OO.
	#find $[installDir] -name *opt-*.pyc -delete
	# Remove all pyc files. There are a ton of them and it is probably faster to let
	# python create the ones it wants at runtime rather than manage in the sstate
	# tarballs and sysroot creation.
	find ${installDir} -name *.pyc -delete

	# Nothing should be looking into $[buildDir] for $[recipe_name]
	sed -i -e 's:'"${buildDir}"':/build/path/unavailable:g' \
		${installDir}/${libdir}/python3.10/config-3.10$PYTHON_ABI*/Makefile
	for c in ${installDir}/${libdir}/python3.10/_sysconfigdata*.py; do
	    log_exec ${recipe_base_name} ${workDir}/reformat_sysconfig.py $c
	done
	rm -f ${installDir}${libdir}/python3.10/__pycache__/_sysconfigdata*.cpython*

	log_run mkdir -p ${installDir}${libdir}/python-sysconfigdata
	sysconfigfile=`find ${installDir} -name _sysconfig*.py`
	sed -i  \
		-e "s,^ 'LIBDIR'.*, 'LIBDIR': '${libdir}'\,,g" \
		-e "s,^ 'INCLUDEDIR'.*, 'INCLUDEDIR': '${includedir}'\,,g" \
		-e "s,^ 'CONFINCLUDEDIR'.*, 'CONFINCLUDEDIR': '${includedir}'\,,g" \
		-e "/^ 'INCLDIRSTOMAKE'/{N; s,/usr/include,${includedir},g}" \
		-e "/^ 'INCLUDEPY'/s,/usr/include,${includedir},g" \
		-e "s,${buildDir},/build/path/unavailable,g" \
		$sysconfigfile
	log_run cp $sysconfigfile ${installDir}${libdir}/python-sysconfigdata/_sysconfigdata.py


	# Unfortunately the following pyc files are non-deterministc due to 'frozenset'
	# being written without strict ordering, even with PYTHONHASHSEED = 0
	# Upstream is discussing ways to solve the issue properly, until then let's
	# just not install the problematic files.
	# More info: http://benno.id.au/blog/2013/01/15/python-determinism
	rm -f ${installDir}${libdir}/python3.10/test/__pycache__/test_range.cpython*
	rm -f ${installDir}${libdir}/python3.10/test/__pycache__/test_xml_etree.cpython*

	# Simil$[AR] to the above, we're getting reproducibility issues with
	# /usr/lib/python3.10/__pycache__/traceback.cpython-310.pyc
	# so remove it too
	rm -f ${installDir}${libdir}/python3.10/__pycache__/traceback.cpython*

	# Remove the opt-1.pyc and opt-2.pyc files. They effectively waste space on embedded
	# style targets as they're only used when python is called with the -O or -OO options
	# which is rare.
	find ${installDir} -name *opt-*.pyc -delete

	# nativepython3 and python3 are in $exec_prefix/bin, not $bindir, as the latter
	# may be moved to $exec_prefix/bin/python3-native...
	if [[ "$bindir " =~ "/python3-native " ]]; then
		log_exec ln -sf python3-native/python3 ${installDir}${bindir}/../python3
	fi	
