#!/bin/bash
# Generic buildstep script

if [ -r "$PLATFORM_LOC/scripts/utils.sh" ]; then
	source "$PLATFORM_LOC/scripts/utils.sh"
else
	source "$script_lib_dir/utils.sh"
fi

generate_cmake_toolchain_file() {
	local cmake_crosscompiling cflags cxxflags
	if $recipe_is_native; then
		cmake_crosscompiling="set( CMAKE_CROSSCOMPILING FALSE )"
		cflags="$BUILD_CFLAGS"
		cxxflags="$BUILD_CXXFLAGS"
	else
		cflags="$TARGET_CFLAGS"
		cxxflags="$TARGET_CXXFLAGS"
	fi
	local arch="$arch_name"
	if [ "$arch" = "powerpc" ]; then arch="ppc"
	elif [ "$arch" = "powerpc64" ]; then arch="ppc64"
	fi
	: ${cmake_cxxflags:=$cmake_cflags}
	: ${cmake_cxx_ldflags:=$cmake_c_ldflags}
	: ${cmake_cxxflags_release:=$cmake_cflags_release}
	if $recipe_is_native; then
		local include_mode="BOTH"
		local library_mode="BOTH"
		local package_mode="BOTH"
		local program_mode="BOTH"
	else
		local include_mode="ONLY"
		local library_mode="ONLY"
		local package_mode="ONLY"
		local program_mode="ONLY"
	fi
	
	cat > $workDir/toolchain.cmake <<EOF
# CMake system name must be something like "Linux".
# This is important for cross-compiling.
$cmake_crosscompiling
set( CMAKE_SYSTEM_NAME Linux )
set( CMAKE_SYSTEM_PROCESSOR $arch )
set( CMAKE_C_COMPILER ${CC} )
set( CMAKE_CXX_COMPILER ${CXX} )
set( CMAKE_ASM_COMPILER ${CC} )
set( CMAKE_AR ${AR} CACHE FILEPATH "Archiver" )
set( CMAKE_C_FLAGS "$cmake_cflags" CACHE STRING "CFLAGS" )
set( CMAKE_CXX_FLAGS "$cmake_cxxflags" CACHE STRING "CXXFLAGS" )
set( CMAKE_ASM_FLAGS "$cmake_cflags" CACHE STRING "ASM FLAGS" )
set( CMAKE_C_FLAGS_RELEASE "$cmake_cflags_release" CACHE STRING "Additional CFLAGS for release" )
set( CMAKE_CXX_FLAGS_RELEASE "$cmake_cxxflags_release" CACHE STRING "Additional CXXFLAGS for release" )
set( CMAKE_ASM_FLAGS_RELEASE "$cmake_cflags_release" CACHE STRING "Additional ASM FLAGS for release" )
set( CMAKE_C_LINK_FLAGS "$cmake_c_ldflags" CACHE STRING "LDFLAGS" )
set( CMAKE_CXX_LINK_FLAGS "$cmake_cxx_ldflags" CACHE STRING "LDFLAGS" )

# SYSROOT is not used, nor needed, by SW4L toolchains
# set( CMAKE_SYSROOT "$SYSROOT_LOC" CACHE STRING "SYSROOT" )

# However we must provide CMAKE_FIND_ROOT_PATH and select ONLY for CMAKE_FIND_ROOT_PATH_MODE_INCLUDE
# and CMAKE_FIND_ROOT_PATH_MODE_LIBRARY (let CMAKE_FIND_ROOT_PATH_MODE_PACKAGE to BOTH for now)
# As we patched cmake to support  CMAKE_FIND_HOST_ROOT_PATH, we are able to also set
# CMAKE_FIND_ROOT_PATH_MODE_PROGRAM to NEVER to only search for native programs
set( CMAKE_FIND_ROOT_PATH $SYSROOT_LOC $NATIVE_SYSROOT_LOC $cmake_perlnative_dir $WEAK_SYSROOT_LOC )
set( CMAKE_FIND_ROOT_PATH_MODE_PACKAGE $package_mode )
set( CMAKE_FIND_ROOT_PATH_MODE_PROGRAM $program_mode )
set( CMAKE_FIND_ROOT_PATH_MODE_LIBRARY $library_mode )
set( CMAKE_FIND_ROOT_PATH_MODE_INCLUDE $include_mode )
set( CMAKE_PROGRAM_PATH "/" )

# We need to set the rpath to the correct directory as cmake does not provide any
# directory as rpath by default
set( CMAKE_INSTALL_RPATH $cmake_rpath )

# Use RPATHs relative to build directory for reproducibility
set( CMAKE_BUILD_RPATH_USE_ORIGIN ON )

# add for non /usr/lib libdir, e.g. /usr/lib64
set( CMAKE_LIBRARY_PATH ${libdir} ${base_libdir})

# add include dir to implicit includes in case it differs from /usr/include
list(APPEND CMAKE_C_IMPLICIT_INCLUDE_DIRECTORIES /usr/include)
list(APPEND CMAKE_CXX_IMPLICIT_INCLUDE_DIRECTORIES /usr/include)

EOF

	if [ -r $workDir/qt.conf ]; then
		cat >> $workDir/toolchain.cmake <<EOF

# Use qt.conf settings
set( ENV{QT_CONF_PATH} $workDir/qt.conf )
EOF
	fi
	
	cat >> $workDir/toolchain.cmake <<EOF

# Use native cmake modules, if any
EOF
	if [ -d "${SYSROOT_LOC}${datadir}/cmake/Modules/" ]; then
		cat >> $workDir/toolchain.cmake <<EOF
list(APPEND CMAKE_MODULE_PATH "${SYSROOT_LOC}${datadir}/cmake/Modules/")
EOF
	fi
	if [ -d "${NATIVE_SYSROOT_LOC}${datadir}/cmake/Modules/" ]; then
		cat >> $workDir/toolchain.cmake <<EOF
list(APPEND CMAKE_MODULE_PATH "${NATIVE_SYSROOT_LOC}${datadir}/cmake/Modules/")
EOF
	fi
	if [ -d "${WEAK_SYSROOT_LOC}${datadir}/cmake/Modules/" ]; then
		cat >> $workDir/toolchain.cmake <<EOF
list(APPEND CMAKE_MODULE_PATH "${WEAK_SYSROOT_LOC}${datadir}/cmake/Modules/")
EOF
	fi
}

do_setup_cmake_options() {
	# Native and cross packages must be configured to execute in the
	# platform-provided native sysroot
	local hbase # main base directory, files that must be on the host
	local tbase # target base, for files that should be on the target
	# --prefix should be on the target (tbase)
	#	except that --bindir, --sbindir and --libexec MUST be on host (hbase)
	# --exec_prefix (so rootdatadir and sysconfdir) should be on target (tbase)
	local opt val var base
	
	# Choose the CMake generator (ensure these are first in cmake options to be nicer)
	if [ -z "$cmake_generator" -o "$cmake_generator" = "Unix Makefiles" ]; then
		cmake_generator='Unix Makefiles'
		cmake_make_program=make
	elif [ "$cmake_generator" = "Ninja" ]; then
		cmake_generator_name="Ninja"
		cmake_make_program=ninja
	else
		warning "Unsupported CMake generator '$cmake_generator'"
		warning "Reverting to 'Unix Makefiles'."
		cmake_generator='Unix Makefiles'
		cmake_make_program=make
	fi
	cmake_options+=( -G "$cmake_generator" "$(requote_arg -DCMAKE_MAKE_PROGRAM=$cmake_make_program)" )
	
	if [ "$DO_NOT_UPDATE_INSTALL_DIRECTORIES" != "true" ]; then
		if $recipe_is_native; then
			hbase="${SYSROOT_LOC%/}"
			tbase="${hbase}"
			if $recipe_is_cross; then
				tbase="${TARGET_SYSROOT_LOC%/}"
			fi
		else
			hbase=""
			tbase=""
		fi
	else
		hbase=""
		tbase=""
	fi
	
	while [ $# -gt 0 ]; do
		opt="$1"
		shift
		case $opt in
			-D*=*)
				val=${opt#-D*=}
#				if [ -z "$val" ]; then continue; fi
				opt=${opt#-D}
				opt=${opt%%=*}
				;;
			-D)
				if [ $# -eq 0 ]; then
					fatal 1 "Incorrect -D option without a value"
				fi
				opt="$1"
				shift
				val=${opt#*=}
#				if [ -z "$val" ]; then continue; fi
				opt=${opt%%=*}
				;;
			-D*)
				val=
				opt=${opt#-D}
				opt=${opt%%=*}
				;;
				
			*)
				cmake_options+=( "$(requote_arg $opt)" )
				continue
				;;
		esac
				
		base=""
		var="${opt,,}"
		if [ "$opt" = "CMAKE_INSTALL_PREFIX" ]; then
			if ! [[ " $val" =~ " $tbase/" ]]; then
				case $val in
					TARGET/*)
						base="$tbase"
						val=${val#TARGET}
						;;
					NATIVE/*)
						base="$hbase"
						val=${val#NATIVE}
						;;
					*)
						base="$tbase"
						;;
				esac
			fi
		fi
		if [ -n "$base" ]; then
			val=${val#/}
			val="$base/$val"
		fi

		eval $var="$(requote_arg $val)"
		cmake_options+=( "-D$opt=${!var}" )
	done

	# Provide sensible defaults for most common variables
	set_cmake_default CMAKE_INSTALL_PREFIX "$prefix"
	set_cmake_default CMAKE_INSTALL_BINDIR "bin"
	set_cmake_default CMAKE_INSTALL_SBINDIR "sbin"
    set_cmake_default CMAKE_INSTALL_LIBEXECDIR "libexec"
	set_cmake_default CMAKE_INSTALL_SYSCONFDIR "/etc"
	set_cmake_default CMAKE_INSTALL_SHAREDSTATEDIR "../com"
	set_cmake_default CMAKE_INSTALL_LOCALSTATEDIR "/var"
	set_cmake_default CMAKE_INSTALL_RUNSTATEDIR ""
	set_cmake_default CMAKE_INSTALL_LIBDIR "lib"
	set_cmake_default CMAKE_INSTALL_INCLUDEDIR "include"
	set_cmake_default CMAKE_INSTALL_OLDINCLUDEDIR "oldinclude"
	set_cmake_default CMAKE_INSTALL_DATAROOTDIR "share"
	set_cmake_default CMAKE_INSTALL_DATADIR ""
	set_cmake_default CMAKE_INSTALL_INFODIR ""
	set_cmake_default CMAKE_INSTALL_LOCALEDIR ""
	set_cmake_default CMAKE_INSTALL_MANDIR ""
	set_cmake_default CMAKE_INSTALL_DOCDIR ""
	set_cmake_default CMAKE_INSTALL_SO_NOEXE "0"

	if $recipe_is_native; then
		set_cmake_default CMAKE_SYSTEM_PROCESSOR "${configure_build_alias%%-*}"
		# Not sure setting CMAKE_CROSSCOMPILING is needed, should be set automatically
		# set_cmake_default CMAKE_CROSSCOMPILING "false"
	else
		set_cmake_default CMAKE_SYSTEM_NAME "Linux"
		local arch="$arch_name"
		if [ "$arch" = "powerpc" ]; then arch="ppc"
		elif [ "$arch" = "powerpc64" ]; then arch="ppc64"
		fi
		set_cmake_default CMAKE_SYSTEM_PROCESSOR "$arch"
		# Not sure setting CMAKE_CROSSCOMPILING is needed, should be set automatically
		# set_cmake_default "CMAKE_CROSSCOMPILING" "true"
	fi
    set_cmake_default CMAKE_VERBOSE_MAKEFILE "1"
    set_cmake_default CMAKE_NO_SYSTEM_FROM_IMPORTED "1"
	set_cmake_default ENABLE_STATIC "False"
	set_cmake_default CMAKE_SOURCE_DIR "$srcDir"
	set_cmake_default CMAKE_BINARY_DIR "$buildDir"
	set_cmake_default CMAKE_TOOLCHAIN_FILE "$workDir/toolchain.cmake"
	
	# Generate the toolchain file (This may deserve a separate task to be ap/pre-pendable)
	generate_cmake_toolchain_file
	
	# Apply the generated defaults
	original_cmake_flags="$cmake_flags"
	if $recipe_is_native; then
		cmake_options+=( "-Wno-dev" )
	fi
	cmake_flags="${cmake_options[*]}" # You should rather not use this, use $cmake_options
}	

do_buildstep_prepend

do_buildstep

do_buildstep_append